(ns wanijo.handler
  (:require [compojure.core :refer [defroutes
                                    routes]]
            [compojure.route :as route]
            [ring.middleware.defaults :refer [wrap-defaults site-defaults]]
            [ring.util.response :as rur]
            [ring.middleware.session.cookie :as session-cookie]
            [wanijo.auth.routes :refer [auth-routes]]
            [wanijo.home.routes :refer [home-routes]]
            [wanijo.schema.routes :refer [schema-routes]]))

(defn- wrap-login-redirect [handler]
  (fn [req]
    (if-not (get-in req [:session :ident])
      (rur/redirect "/login")
      (handler req))))

(defroutes app-routes
  (routes auth-routes)
  (wrap-login-redirect
   (routes home-routes
           schema-routes))
  (route/not-found "Not Found"))

(def app
  (-> app-routes
      (wrap-defaults (assoc-in site-defaults
                               [:session :store]
                               (session-cookie/cookie-store {:key "1234567890123456"})))))
